Examples
========
Pygame Turbo has a collection of examples which you can use to learn by reading
or modifying the code of the game. You can also play with them! These examples
aren't provided with a normal installation of Pygame Turbo but they're available
in the source code repository. To download them, follow the following steps:

- Download the source code of Pygame Turbo on the
  `GitHub repository <https://github.com/Mambouna/pgturbo>`_ by clicking in the
  big green button and choosing **Download ZIP**
- Copy the ``examples`` folder whatever you want.
- Delete the ZIP and the source code if you want to save space on your disk.

Now you can play with them as another game that you might created. For example,
to run the pong game, you should run::

    pgtrun examples/pong

Reading & editing the source code is a great way to learn to code, so start
hacking the code!

List of example games
---------------------

Asteroids
^^^^^^^^^
.. image:: _static/asteroids.png
   :alt: Asteroids
   :height: 500
   :align: center

To play, run::

    pgtrun examples/asteroids

Basic
^^^^^
This a collection of simple examples that you can use to learn who to use key
parts of Pygame Turbo. Some of them are examples explained in the documentation.

Flappybird
^^^^^^^^^^
.. image:: _static/flappybird.png
   :alt: Flappybird
   :height: 500
   :align: center

To play, run::

    pgtrun examples/flappybird

Lander
^^^^^^
.. image:: _static/lander.png
   :alt: Lander
   :height: 500
   :align: center

To play, run::

    pgtrun examples/lander

Memory
^^^^^^
.. image:: _static/memory.png
   :alt: Memory
   :height: 500
   :align: center

To play, run::

    pgtrun examples/memory

Mines
^^^^^
.. image:: _static/mines.png
   :alt: Mines
   :height: 300
   :align: center

To play, run::

    pgtrun examples/mines

Pong
^^^^
.. image:: _static/pong.png
   :alt: Pong
   :height: 500
   :align: center

To play, run::

    pgtrun examples/pong

Snake
^^^^^
.. image:: _static/snake.png
   :alt: Snake
   :height: 300
   :align: center

To play, run::

    pgtrun examples/snake

Tetra puzzle
^^^^^^^^^^^^
.. image:: _static/tetra-puzzle.png
   :alt: Tetra Puzzle
   :height: 500
   :align: center

To play, run::

    pgtrun examples/tetra_puzzle

Tron
^^^^
.. image:: _static/tron.png
   :alt: Tron
   :height: 500
   :align: center

To play, run::

    pgtrun examples/tron
